@@ -44,9 +44,10 @@
 #'                      other functions that usually would take an
 #'                      \code{edsurvey.data.frame}. This \code{data.frame} also is called a \code{light.edsurvey.data.frame}.
 #'                      See Description section in \code{\link{edsurvey.data.frame}} for
-#'                      more information on \code{light.edsurvey.data.frame}.
+#'                      more information on \code{light.edsurvey.data.frame}. 
 #' @param returnJKreplicates a logical value indicating if JK replicate weights
 #'                           should be returned. Defaults to \code{TRUE}.
+#'                    
 #'
 #' @details By default, an \code{edsurvey.data.frame} does not have data read
 #' into memory until \code{getData} is called and returns a data frame.
@@ -107,7 +108,7 @@ getData <- function(data,
   if(!is.logical(defaultConditions)) stop("The ", sQuote("defaultConditions"), " argument must be logical.")
   if(!is.null(recode) & !is.list(recode)) stop(paste0("The ", sQuote("recode"), " argument must be a list."))
   if(is.null(varnames) & is.null(formula)) stop(paste0("At least one of ", sQuote("varnames"), " and ", sQuote("formula"), " must be not NULL."))
-
+  
   # for edsurvey.data.frame.list, just return a list of results
   if (inherits(sdf, c("edsurvey.data.frame.list"))) {
     res <- itterateESDFL(match.call(),sdf)
@@ -116,7 +117,8 @@ getData <- function(data,
     }
     return(res)
   }
-
+  survey <- getAttributes(sdf, "survey")
+  
   if(!inherits(sdf, "edsurvey.data.frame")) {
     # if this is a light.edsurvey.data.frame
     if(!missing(defaultConditions)) {
@@ -132,7 +134,7 @@ getData <- function(data,
 
   # get variables from formula
   formulaVars <- all.vars(formula)
-  varnames <-c(varnames,formulaVars)
+  varnames <- c(varnames, formulaVars)
   #Retrieve the default conditions
   dConditions <- NULL
   varNamesDefaults <- c()
@@ -163,14 +165,12 @@ getData <- function(data,
   #Retrieve user conditions
   userConditions <- getAttributes(sdf, "userConditions")
   varNamesConditions <- c()
-  if(length(userConditions)>0) {
-    for (i in c(1:length(userConditions))) {
-      if (!is.null(names(userConditions)[i]) && names(userConditions)[i] %in% "recode") {
-        # do nothing, these variables are not loaded in unless needed
-      } else {
-        condition <- userConditions[[i]]
-        varNamesConditions <- c(varNamesConditions, all.vars(condition))
-      }
+  for (i in seq_along(userConditions)) {
+    if (!is.null(names(userConditions)[i]) && names(userConditions)[i] %in% "recode") {
+      # do nothing, these variables are not loaded in unless needed
+    } else {
+      condition <- userConditions[[i]]
+      varNamesConditions <- c(varNamesConditions, all.vars(condition))
     }
   }
 
@@ -181,15 +181,28 @@ getData <- function(data,
   vars <- c()
   v <-c ()
 
+  hasIRTAttr <- has_IRTAttributes(sdf, errorCheck = FALSE) #in mml.sdf.R file, no need to throw error if IRT not set
   hpv <- hasPlausibleValue(varnames, sdf) # Boolean vector that is TRUE when the variable has plausible values
   iw <- isWeight(varnames, sdf) # Boolean vector that is TRUE when the variable is a weight
   vars <- c(vars, varnames[!(iw | hpv)])
   vars_exclude_omitted <- c()
-  if(sum(hpv) > 0) {
-    pvs <- getPlausibleValue(varnames[hpv], sdf)
-    vars_exclude_omitted <- c(vars_exclude_omitted, pvs[-1])
-    vars <- c(vars, pvs)
-  }
+  
+  if(any(hpv) || hasIRTAttr) { #if SDF has IRT attributes, we need to ensure those items are excluded from the 'omittedLevels' checks down the line
+    if(any(hpv)){
+      pvs <- getPlausibleValue(varnames[hpv], sdf)
+      vars_exclude_omitted <- c(vars_exclude_omitted, pvs[-1])
+      vars <- c(vars, pvs)
+    }
+    if(hasIRTAttr){
+      if (any(hpv)){ #test if any vars are plausible value names
+        items <- getAllItems(sdf, varnames[hpv]) #suitable for TIMSS for subject
+      } else {
+        items <- getAllItems(sdf, NULL) #suitable for NAEP, as all items are returned
+      }
+      vars_exclude_omitted <- c(vars_exclude_omitted, items)
+    }
+  }# if(any(hpv) || hasIRTAttr)
+
   #getAllPSUVar and getallStratumVar are defined in getData.R to return a vector of all the PSU & Stratum variables associated with the edsurvey.data.frame/light.edsurvey.data.frame
   vars_exclude_omitted <- c(vars_exclude_omitted, getAllPSUVar(sdf), getAllStratumVar(sdf))
   if(sum(iw)>0 & returnJKreplicates == TRUE) {
@@ -204,7 +217,6 @@ getData <- function(data,
   }
   # remove any duplicates (e.g. because part of default conditions and requested)
   varnames <- unique(vars)
-
   # expand varnamesAllConditions when it has a variable with PVs or is a weight
   # also make varnamesTotal
   vars <- c()
@@ -252,7 +264,7 @@ getData <- function(data,
 
     #loop through dataList in reverse order to determine the highest levels that have requested variables.  mark those levels, and their required parent levels as 'TRUE'
     for(dlevel in rev(sdf$dataList)){
-      #check if the level requires to be merged either by: 1) forceMerged flag is TRUE. 2) Has a variable requested by the user that is not contained in the levels 'ignoreVars' list.
+      #check if the level requires to be merged either by: 1) forceMerged Flag is TRUE. 2) Has a variable requested by the user that is not contained in the levels 'ignoreVars' list.
       if(dlevel$forceMerge || any(dlevel$fileFormat$variableName[!dlevel$fileFormat$variableName %in% dlevel$ignoreVars] %in% uncachedVars)){
         mergeLevels[names(mergeLevels)==dlevel$levelLabel | names(mergeLevels) %in% dlevel$parentMergeLevels] <- TRUE #specify which levels we need to specifically loop through/merge
 
@@ -263,6 +275,7 @@ getData <- function(data,
       }
     }#end for(dlevel in rev(sdf$dataList))
     #loop through each data item and see if any variables are requested and process accordingly to the dataList rules
+    
     for(dlevel in sdf$dataList){
       if(dlevel$forceMerge || mergeLevels[names(mergeLevels)==dlevel$levelLabel]==TRUE){
         laf <- dlevel$lafObject
@@ -366,7 +379,7 @@ getData <- function(data,
     #apply the decimal conversion prior to applying the labels AND the merge in case we have a decimal value used as the key in the key/value label or need to adjust any weights
     #PISA reads in csv files so no need to convert to decimal values
     if (sdf$reqDecimalConversion==TRUE) {
-      for(i in c(1:length(colnames(sdf)))) {
+      for(i in seq_along(variables)) {
         varn <- variables[i] # the variable being considered
         decLen <- decimals[i]
         decLen[is.na(decLen)] <- 0 #use a 0 if NA is specified for decimal length (character value)
@@ -503,148 +516,146 @@ getData <- function(data,
     }
 
     #Apply user conditions (i.e. subset, recode)
-    if(length(userConditions)>0) {
-      for (i in c(1:length(userConditions))) {
-        if (!is.null(names(userConditions)[i]) && names(userConditions)[i] %in% "recode") {
-          recode <- userConditions[[i]]
-          if(!is.null(recode)) {
-            # apply recodes
-            for (i in 1:length(recode)){
-              if(names(recode)[i] %in% colnames(data)) {
-                ni <- names(recode)[i]
-                from <- recode[[i]]$from
-                to <- recode[[i]]$to
-                if (length(to) > 1) {
-                  stop(paste0("More than one 'To' value found in the ", sQuote(ni) ," element of the 'recode' argument."))
+    for (i in seq_along(userConditions)) {
+      if (!is.null(names(userConditions)[i]) && names(userConditions)[i] %in% "recode") {
+        recode <- userConditions[[i]]
+        if(!is.null(recode)) {
+          # apply recodes
+          for (i in 1:length(recode)){
+            if(names(recode)[i] %in% colnames(data)) {
+              ni <- names(recode)[i]
+              from <- recode[[i]]$from
+              to <- recode[[i]]$to
+              if (length(to) > 1) {
+                stop(paste0("More than one 'To' value found in the ", sQuote(ni) ," element of the 'recode' argument."))
+              }
+
+              badFrom <- c() #levels with incorrect recodes
+              if(inherits(data[,ni], "factor")) {
+                newto <- to
+                if(to %in% from) { # remove degenerate recode
+                  from <- from[!from %in% to]
                 }
-
-                badFrom <- c() #levels with incorrect recodes
-                if(inherits(data[,ni], "factor")) {
-                  newto <- to
-                  if(to %in% from) { # remove degenerate recode
-                    from <- from[!from %in% to]
-                  }
-                  labs <- levels(data[,ni]) # used for both lfactors and factors
-                  if(newto %in% labs) { # this is not a new label
-                    newto <- NULL
-                  }
-                  tmp <- as.character(data[,ni])
-                  if(inherits(data[,ni],"lfactor")) { # it is an lfactor
-                    levs <- llevels(data[,ni])
-                    # in case of lfactor:
-                    # + from can be numeric or character
-                    # + to can be numeric or character
-                    # To simplify the code, if to is a numeric, we will coerce it to character
-                    if (is.numeric(to)) {
-                      if (!to %in% levs) {
-                        labs <- c(labs, as.character(to)) # since there are no labels provided, we will use character format of levels
-                        levs <- c(levs, to)
-                      }
-                      toNum <- to
-                      to <- labs[levs==to]
-                    } else {
-                      if (!to %in% labs) {
-                        labs <- c(labs,to)
-                        toNum <- max(levs,na.rm=TRUE) + 1
-                        levs <- c(levs, toNum)
-                      } else {
-                        toNum <- levs[which(to %in% labs)]
-                      }
-                    }
-                    # after the code above, to is always a character label
-
-                    # from can be a vector of mixed numeric and character values
-                    # fromNum: numeric values in from
-                    # fromChar: character values in from
-                    suppressWarnings(fromNum <- as.numeric(from)) # numeric from variables
-                    fromChar <- from[is.na(fromNum)]# character from variables
-                    # numeric from variables
-                    fromNum <- fromNum[!is.na(fromNum)]
-
-                    # changing tmp according to numeric values of from
-                    if(length(fromNum)>0) {
-                      tmp_numeric <- lfactors:::switchllevels(data[,ni])
-                      tmp[tmp_numeric %in% fromNum] <- to
-                      if(any(!fromNum %in% levs)) {
-                        #add any missing levels to missing list
-                        badFrom <- fromNum[!fromNum %in% levs]
-                      }
-                      labs <- labs[!levs %in% setdiff(fromNum,toNum)]
-                      levs <- levs[!levs %in% setdiff(fromNum,toNum)]
-                    }
-                    # changing tmp according to character values of from
-                    if(length(fromChar)>0) {
-                      tmp[tmp %in% fromChar] <- to
-                      if(any(!fromChar %in% labs)) {
-                        badFrom <- c(badFrom, fromChar[!fromChar %in% labs])
-                      }
-                      levs <- levs[!labs %in% setdiff(fromChar, to)]
-                      labs <- labs[!labs %in% setdiff(fromChar, to)]
-                    }
-                    # Now we need to call lfactors again to make sure levels are mapped correctly to modified character vectors
-                    data[,ni] <- lfactor(tmp, levels=levs, labels=labs, exclude = NULL)
-                  } else { # end if(inherits(x[,ni],"lfactor"))
-                    # it is a base r factor so from and to have to be character
-                    tmp[tmp %in% from] <- to
-                    if(any(!from %in% labs)) {
-                      #add any missing levels to missing list
-                      badFrom <- c(badFrom,from[!from %in% labs])
+                labs <- levels(data[,ni]) # used for both lfactors and factors
+                if(newto %in% labs) { # this is not a new label
+                  newto <- NULL
+                }
+                tmp <- as.character(data[,ni])
+                if(inherits(data[,ni],"lfactor")) { # it is an lfactor
+                  levs <- llevels(data[,ni])
+                  # in case of lfactor:
+                  # + from can be numeric or character
+                  # + to can be numeric or character
+                  # To simplify the code, if to is a numeric, we will coerce it to character
+                  if (is.numeric(to)) {
+                    if (!to %in% levs) {
+                      labs <- c(labs, as.character(to)) # since there are no labels provided, we will use character format of levels
+                      levs <- c(levs, to)
                     }
+                    toNum <- to
+                    to <- labs[levs==to]
+                  } else {
                     if (!to %in% labs) {
                       labs <- c(labs,to)
+                      toNum <- max(levs,na.rm=TRUE) + 1
+                      levs <- c(levs, toNum)
+                    } else {
+                      toNum <- levs[which(to %in% labs)]
                     }
-                    data[,ni] <- factor(tmp, levels=labs)
                   }
-                } else { # end if(inherits(x[,ni], "factor"))
-                  # recode for non factors
-                  if(any(!from %in% data[,ni])) {
-                    badFrom <- from[!from %in% data[,ni]]
+                  # after the code above, to is always a character label
+
+                  # from can be a vector of mixed numeric and character values
+                  # fromNum: numeric values in from
+                  # fromChar: character values in from
+                  suppressWarnings(fromNum <- as.numeric(from)) # numeric from variables
+                  fromChar <- from[is.na(fromNum)]# character from variables
+                  # numeric from variables
+                  fromNum <- fromNum[!is.na(fromNum)]
+
+                  # changing tmp according to numeric values of from
+                  if(length(fromNum)>0) {
+                    tmp_numeric <- lfactors:::switchllevels(data[,ni])
+                    tmp[tmp_numeric %in% fromNum] <- to
+                    if(any(!fromNum %in% levs)) {
+                      #add any missing levels to missing list
+                      badFrom <- fromNum[!fromNum %in% levs]
+                    }
+                    labs <- labs[!levs %in% setdiff(fromNum,toNum)]
+                    levs <- levs[!levs %in% setdiff(fromNum,toNum)]
                   }
-                  data[,ni][data[,ni] %in% from] <- to
-                } # end else for if(inherits(data[,ni], "factor"))
-                if(length(badFrom) > 0) {
-                  warning(paste0("When recoding, could not find the level(s) ",
-                                 pasteItems(dQuote(badFrom), final="or"),
-                                 " in the variable ", dQuote(ni), "."))
+                  # changing tmp according to character values of from
+                  if(length(fromChar)>0) {
+                    tmp[tmp %in% fromChar] <- to
+                    if(any(!fromChar %in% labs)) {
+                      badFrom <- c(badFrom, fromChar[!fromChar %in% labs])
+                    }
+                    levs <- levs[!labs %in% setdiff(fromChar, to)]
+                    labs <- labs[!labs %in% setdiff(fromChar, to)]
+                  }
+                  # Now we need to call lfactors again to make sure levels are mapped correctly to modified character vectors
+                  data[,ni] <- lfactor(tmp, levels=levs, labels=labs, exclude = NULL)
+                } else { # end if(inherits(x[,ni],"lfactor"))
+                  # it is a base r factor so from and to have to be character
+                  tmp[tmp %in% from] <- to
+                  if(any(!from %in% labs)) {
+                    #add any missing levels to missing list
+                    badFrom <- c(badFrom,from[!from %in% labs])
+                  }
+                  if (!to %in% labs) {
+                    labs <- c(labs,to)
+                  }
+                  data[,ni] <- factor(tmp, levels=labs)
                 }
-              }# end if(names(recode)[i] %in% colnames(data))
-            } # end for (i in 1:length(recode))
-          } # end if(!is.null(recode))
-        } else { # other userConditions are specified in subset
-          condition <- userConditions[[i]]
-          r <- eval(condition, data)
-          r <- ifelse(is.na(r), FALSE, r) #remove NA
-          data <- data[which(r), , drop=FALSE]
-        }
-      }#end for (i in c(1:length(userConditions)))
-    } # end if(length(userConditions) > 0)
+              } else { # end if(inherits(x[,ni], "factor"))
+                # recode for non factors
+                if(any(!from %in% data[,ni])) {
+                  badFrom <- from[!from %in% data[,ni]]
+                }
+                data[,ni][data[,ni] %in% from] <- to
+              } # end else for if(inherits(data[,ni], "factor"))
+              if(length(badFrom) > 0) {
+                warning(paste0("When recoding, could not find the level(s) ",
+                               pasteItems(dQuote(badFrom), final="or"),
+                               " in the variable ", dQuote(ni), "."))
+              }
+            }# end if(names(recode)[i] %in% colnames(data))
+          } # end for (i in 1:length(recode))
+        } # end if(!is.null(recode))
+      } else { # other userConditions are specified in subset
+        condition <- userConditions[[i]]
+        r <- eval(condition, data)
+        r <- ifelse(is.na(r), FALSE, r) #remove NA
+        data <- data[which(r), , drop=FALSE]
+      }
+    }#end for (i in seq_along(userConditions))
 
     # apply omittedLevels when TRUE or equal to some levels
     # this code should execute on all of the variables when omittedLevels is TRUE
-    flag <- FALSE # set to TRUE when using ommittedLevels in some capacity
+    omittedLevelsFlag <- FALSE # set to TRUE when using ommittedLevels in some capacity
     # lev variable is the levels that are being omitted
-    if(omittedLevels == TRUE) {
+    if(all(omittedLevels %in% TRUE)) {
       lev <- unlist(sdf$omittedLevels) # here we know it is an edsurvey.data.frame
-      flag <- TRUE
+      omittedLevelsFlag <- TRUE
     }
     if(!is.logical(omittedLevels)) {
       lev <- omittedLevels
-      flag <- TRUE
+      omittedLevelsFlag <- TRUE
     }
 
-    #flag variable is calculated above to determine if omitted values should be excluded from results
-    if(flag) {
+    #omittedLevelsFlag variable is calculated above to determine if omitted values should be excluded from results
+    if(omittedLevelsFlag) {
       keep <- rep(0, nrow(data))
       for (i in 1:length(varnamesTotal)) {
         vari <- varnamesTotal[i]
         if(! vari %in% vars_exclude_omitted) {
           # omit data at these levels
-          keep <- keep + (data[ , vari] %in% lev)
+          keep <- keep | (data[ , vari] %in% lev)
         }
       }
-      if(sum(keep>0) > 0) {
+      if(any(!keep)) {
         # only omit if something gets omitted
-        data <- data[keep==0, , drop=FALSE]
+        data <- data[!keep, , drop=FALSE]
       }
     }
 
@@ -669,17 +680,17 @@ getData <- function(data,
     data <- sdf
 
     # check omittedLevels argument to see if should be applied
-    flag <- FALSE
-    if(omittedLevels == TRUE) {
+    omittedLevelsFlag <- FALSE
+    if(omittedLevels[1] == TRUE) {
       lev <- unlist(attributes(sdf)$omittedLevels) # this is a light.edsurvey.data.frame
-      flag <- TRUE
+      omittedLevelsFlag <- TRUE
     }
     if(!is.logical(omittedLevels)) {
       lev <- omittedLevels
-      flag <- TRUE
+      omittedLevelsFlag <- TRUE
     }
     # if it should be applied, apply omittedLevels
-    if(flag) {
+    if(omittedLevelsFlag) {
       keep <- rep(0, nrow(data))
       for (i in 1:length(varnamesTotal)) {
         vari <- varnamesTotal[i]
@@ -734,7 +745,6 @@ getData <- function(data,
     # reset userConditions to remove recode (because its already applied)
     class(data) <- c("light.edsurvey.data.frame", class(data))
     data <- setAttributes(data,"userConditions", userConditions[which(!names(userConditions) %in% "recode")])
-
     return(data)
   } # end if(addAttributes)
   if(nrow(data) == 0) {
