@@ -1,5 +1,5 @@
 \dontrun{
-wrkFld <- "C:/HSB/SOPHOMORE"
+wrkFld <- "~/HSB/SOPHOMORE"
 
 dataPath <- file.path(wrkFld, "REVISED_ASCII", "HSO8092_REV.PRI")
 sasPath <- file.path(wrkFld, "SAS_EXTRACT_LOGIC", "HSBso_READ_HSO8092.SAS")
