@@ -270,7 +270,7 @@ es5REF <- c("",
             "   Male  2 or 3 times a week  Some ed after H.S. 289 303.0328  32.72870270  2.18848867 286.4461  2.983216",
             "   Male  2 or 3 times a week        I Don't Know 193 210.3634  22.72005267  1.86922563 264.9552  3.162175",
             "   Male  2 or 3 times a week             Omitted   9   8.7073   0.94042174  0.38952042 283.6697 24.843980",
-            "   Male  2 or 3 times a week            Multiple   1   0.4306   0.04650645  0.04655901       NA        NA",
+            "   Male  2 or 3 times a week            Multiple   1   0.4306   0.04650645  0.04655901 248.7740        NA",
             "   Male            Every day Did not finish H.S.  90  85.7821  11.36255833  1.64520050 257.4599  5.883638",
             "   Male            Every day      Graduated H.S. 215 213.8557  28.32698041  1.95061779 273.4292  3.602727",
             "   Male            Every day  Some ed after H.S. 229 227.9686  30.19635233  2.14371557 283.3870  3.215319",
@@ -287,14 +287,14 @@ es5REF <- c("",
             "   Male             Multiple      Graduated H.S.   0   0.0000   0.00000000          NA       NA        NA",
             "   Male             Multiple  Some ed after H.S.   3   1.5787  39.28384801 21.17715124 300.7674 10.920051",
             "   Male             Multiple        I Don't Know   0   0.0000   0.00000000          NA       NA        NA",
-            "   Male             Multiple             Omitted   1   2.4400  60.71615199 21.17715124       NA        NA",
+            "   Male             Multiple             Omitted   1   2.4400  60.71615199 21.17715124 239.0700        NA",
             "   Male             Multiple            Multiple   0   0.0000   0.00000000          NA       NA        NA",
             " Female Never or hardly ever Did not finish H.S. 257 265.8121  22.66087809  1.83211169 257.9069  2.866308",
             " Female Never or hardly ever      Graduated H.S. 370 393.8865  33.57941176  2.35231946 266.8433  2.494888",
             " Female Never or hardly ever  Some ed after H.S. 194 198.6895  16.93857630  1.10226541 276.9228  3.159055",
             " Female Never or hardly ever        I Don't Know 287 308.6794  26.31537937  1.83786094 255.5826  2.689146",
             " Female Never or hardly ever             Omitted   5   5.2627   0.44865303  0.26376131 304.8005 19.068264",
-            " Female Never or hardly ever            Multiple   1   0.6698   0.05710145  0.05715608       NA        NA",
+            " Female Never or hardly ever            Multiple   1   0.6698   0.05710145  0.05715608 243.7680        NA",
             " Female Once every few weeks Did not finish H.S. 192 201.7517  17.95235277  1.22332270 263.7769  3.318216",
             " Female Once every few weeks      Graduated H.S. 380 393.1678  34.98501892  1.82186485 267.4015  2.371553",
             " Female Once every few weeks  Some ed after H.S. 293 279.0163  24.82754319  1.55330632 280.9736  2.213633",
@@ -319,7 +319,7 @@ es5REF <- c("",
             " Female            Every day        I Don't Know 193 203.3300  17.81376022  1.49573474 248.0493  3.198495",
             " Female            Every day             Omitted   2   0.2870   0.02514410  0.02502224 231.7420        NA",
             " Female            Every day            Multiple   3   3.5403   0.31016601  0.24172024 269.4525 11.741929",
-            " Female              Omitted Did not finish H.S.   1   1.7223   2.13525117  2.07803300       NA        NA",
+            " Female              Omitted Did not finish H.S.   1   1.7223   2.13525117  2.07803300 279.7860        NA",
             " Female              Omitted      Graduated H.S.   5  11.3386  14.05722518  8.22953780 215.9616 43.566724",
             " Female              Omitted  Some ed after H.S.   2   0.9568   1.18620932  1.04126567 304.0706 64.226485",
             " Female              Omitted        I Don't Know   4   6.6022   8.18519148  4.83360599 182.8789 22.518459",
@@ -328,7 +328,7 @@ es5REF <- c("",
             " Female             Multiple Did not finish H.S.   0   0.0000   0.00000000          NA       NA        NA",
             " Female             Multiple      Graduated H.S.   0   0.0000   0.00000000          NA       NA        NA",
             " Female             Multiple  Some ed after H.S.   0   0.0000   0.00000000          NA       NA        NA",
-            " Female             Multiple        I Don't Know   1   0.1435 100.00000000          NA       NA        NA",
+            " Female             Multiple        I Don't Know   1   0.1435 100.00000000          NA 293.5940        NA",
             " Female             Multiple             Omitted   0   0.0000   0.00000000          NA       NA        NA",
             " Female             Multiple            Multiple   0   0.0000   0.00000000          NA       NA        NA"
 )
@@ -369,7 +369,7 @@ estwith0REF <- c("",
                  "        I Don't Know Harder than others  274  273.8016 10.53607611  0.71134338 255.4384  2.958810",
                  "        I Don't Know        Much harder  103   89.4648  3.44266777  0.46714337 243.9997  4.759095",
                  "        I Don't Know            Omitted   93  101.9524  3.92319930  0.56310218 237.8497  3.975815",
-                 "        I Don't Know           Multiple    1    0.8133  0.03129635  0.03132223       NA        NA",
+                 "        I Don't Know           Multiple    1    0.8133  0.03129635  0.03132223 292.2200        NA",
                  "             Omitted Easier than others   31   37.3172 17.01982100  3.41767224 286.8190  8.815679",
                  "             Omitted  As hard as others   29   27.4135 12.50289044  3.13717532 258.3821  7.985184",
                  "             Omitted Harder than others    7    5.5018  2.50928931  1.09558321 252.8294 32.209054",
@@ -379,8 +379,8 @@ estwith0REF <- c("",
                  "            Multiple Easier than others   13    8.0853 32.81531568 12.57870084 252.9200  8.349768",
                  "            Multiple  As hard as others   13   13.8744 56.31118399  9.39004975 251.1944  7.175494",
                  "            Multiple Harder than others    0    0.0000  0.00000000          NA       NA        NA",
-                 "            Multiple        Much harder    1    0.1435  0.58241473  0.61353570       NA        NA",
-                 "            Multiple            Omitted    1    2.5356 10.29108560 10.49245307       NA        NA",
+                 "            Multiple        Much harder    1    0.1435  0.58241473  0.61353570 240.2340        NA",
+                 "            Multiple            Omitted    1    2.5356 10.29108560 10.49245307 280.2800        NA",
                  "            Multiple           Multiple    0    0.0000  0.00000000          NA       NA        NA"
 )
 logit1REF <- c("",
