@@ -105,11 +105,11 @@ pctREF <- c("Percentile",
             "",
             " percentile estimate      se     df confInt.ci_lower confInt.ci_upper", 
             "          0   248.67 14.4169  0.000           248.67           248.67", 
-            "          1   345.74  6.0948 19.316           328.63           357.17", 
-            "         25   479.13  2.3386 73.969           473.46           484.68", 
-            "         50   530.75  2.5736 72.190           525.49           535.98", 
-            "         75   581.48  2.9514 84.268           576.04           586.74", 
-            "         99   692.29  4.0554 12.058           686.24           702.97", 
+            "          1   345.74  6.0948 19.316           328.83           357.01", 
+            "         25   479.13  2.3386 73.969           473.58           484.61", 
+            "         50   530.75  2.5736 72.190           525.59           535.87", 
+            "         75   581.48  2.9514 84.268           576.13           586.66", 
+            "         99   692.29  4.0554 12.058           686.37           702.66", 
             "        100   781.63 18.7631  0.000           781.63           781.63")
 
 logit1REF <- c("",
@@ -206,7 +206,8 @@ mmlIntREF <- c("  (Intercept) Population SD ",
 
 mmlSumREF <- c("Call:",
                "mml.sdf(formula = mmat ~ 1, data = usa4.15, weightVar = \"totwgt\", ",
-               "    verbose = TRUE)", "Summary Call:",
+               "    verbose = FALSE)",
+               "Summary Call:",
                "summary.mml.sdf(object = mml1)",
                "",
                "Summary:",
@@ -217,7 +218,8 @@ mmlSumREF <- c("Call:",
                "",
                "Residual Variance Estimate:",
                "              Estimate StdErr",
-               "Population SD    81.72  1.422", "",
+               "Population SD    81.72  1.422",
+               "",
                "Convergence = converged",
                "Iterations = 12",
                "LogLike = -52453394.92",
